Ping Rest API — Rucio 1.2 documentation

# Ping Rest API

Overview

Resource | Operation | Description
--- | --- | ---
Ping | GET /ping/ | Ping the server.

Details

`GET` `/ping/`

  Ping the server and retrieve the server version.

  Example request:

      GET /ping HTTP/1.1
      Host: rucio-server.com
      Accept: application/json

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type: application/json

      {"version": "1.15.0"}

  Status Codes: | 200 OK – OK. 500 Internal Server Error – Internal Error.
  Returns: | JSON dictionary with the version.